<?php namespace RVR\Controller;

use RVR\PersistentData\Model\User;
use RVR\Repository\CommunityMemberRepository;
use SokoWeb\Interfaces\Authentication\IAuthenticationRequired;
use SokoWeb\Interfaces\Request\IRequest;
use SokoWeb\Interfaces\Response\IContent;
use SokoWeb\Response\HtmlContent;

class HomeController implements IAuthenticationRequired
{
    private IRequest $request;

    private CommunityMemberRepository $communityMemberRepository;

    public function __construct(IRequest $request)
    {
        $this->request = $request;
        $this->communityMemberRepository = new CommunityMemberRepository();
    }

    public function isAuthenticationRequired(): bool
    {
        return true;
    }

    public function getHome(): IContent
    {
        /**
        * @var User $user
        */
        $user = $this->request->user();

        $ownCommunityMembers = $this->communityMemberRepository->getAllByUser($user, true);
        $communities = [];
        foreach ($ownCommunityMembers as $ownCommunityMember) {
            $communities[] = $ownCommunityMember->getCommunity();
        }
        usort($communities, function($a, $b) {
            return strnatcmp($a->getName(), $b->getName());
        });

        return new HtmlContent('home', [
            'communities' => $communities,
            'upcomingEvents' => []
        ]);
    }
}
